# Paranet Agent Framework for Python

## Documentation

[API Reference](https://grokit-data.github.io/py-paranet-sdk)

## Install

For version `x.y.z`:
```
python -m pip install paranet_agent-x.y.z-py3-none-any.whl
```

## Create package

1. Update version in `paranet_agent/__init__.py` and `setup.py`
2. Delete files in `./dist`
3. Run `python setup.py sdist bdist_wheel`